const csvUrl =
  'https://gist.githubusercontent.com/Sannihitha23/a65e3e4ddb3f173e7d897cf72c79f8c6/raw/e56782199c5daed491e92df29682a5afa425b491/population.csv';

// Load data from the CSV file using D3
d3.csv(csvUrl)
  .then(function (data) {
    // Convert string values to numbers if needed
    data.forEach(function (d) {
      d.Country = d.Country; // Corrected property name
      d.Population = +d.Population; // Corrected property name
    });

    // Set up dimensions for the chart
    const width = 800;
    const height = 400;
    const margin = {
      top: 20,
      right: 20,
      bottom: 50,
      left: 50,
    };
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;

    // Create SVG element
    const svg = d3
      .select('body')
      .append('svg')
      .attr('id', 'areachart') // Added id to select the SVG later
      .attr('width', width)
      .attr('height', height);

    // Create scales
    const xScale = d3
      .scaleBand()
      .domain(data.map((d) => d.Country)) // Corrected property name
      .range([margin.left, innerWidth])
      .padding(0.1);

    const yScale = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.Population)]) // Corrected property name
      .nice()
      .range([innerHeight, margin.top]);

    // Create area generator
    const area = d3
      .area()
      .x((d) => xScale(d.Country) + xScale.bandwidth() / 2) // Corrected property name
      .y0(innerHeight)
      .y1((d) => yScale(d.Population)); // Corrected property name

    // Append area to SVG
    svg
      .append('path')
      .datum(data)
      .attr('fill', 'steelblue')
      .attr('d', area);

    // Create axes
    const xAxis = d3.axisBottom(xScale);
    const yAxis = d3.axisLeft(yScale);

    // Append axes to SVG
    svg
      .append('g')
      .attr('transform', `translate(0, ${innerHeight})`)
      .call(xAxis)
      // X-axis label
      .append('text')
      .attr('x', innerWidth / 2)
      .attr('y', margin.bottom - 10)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .text('Country'); // Corrected axis label

    svg
      .append('g')
      .attr('transform', `translate(${margin.left}, 0)`)
      .call(yAxis)
      // Y-axis label
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('x', -innerHeight / 2)
      .attr('y', -margin.left + 15)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .text('Population'); // Corrected axis label
  })
  .catch(function (error) {
    console.log('Error loading data: ', error);
  });
